[PATCH 01/11] dm: core: Rename device_bind() to device_bind_offset()

Simon Glass sjg at chromium.org
Sun Nov 29 01:50:00 CET 2020


This function is not necessary anymore, since device_bind_ofnode() does
the same thing and works with both flattree and livetree.

Rename it to indicate that it is special.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

 arch/x86/cpu/apollolake/spl.c               | 2 +-
 drivers/clk/clk.c                           | 2 +-
 drivers/core/device.c                       | 6 +++---
 drivers/gpio/mt7621_gpio.c                  | 4 ++--
 drivers/gpio/s5p_gpio.c                     | 4 ++--
 drivers/gpio/sunxi_gpio.c                   | 4 ++--
 drivers/gpio/tegra186_gpio.c                | 4 ++--
 drivers/gpio/tegra_gpio.c                   | 5 +++--
 drivers/net/mvpp2.c                         | 2 +-
 drivers/pinctrl/broadcom/pinctrl-bcm283x.c  | 5 +++--
 drivers/pinctrl/meson/pinctrl-meson.c       | 2 +-
 drivers/pinctrl/mscc/pinctrl-jr2.c          | 4 ++--
 drivers/pinctrl/mscc/pinctrl-luton.c        | 4 ++--
 drivers/pinctrl/mscc/pinctrl-ocelot.c       | 4 ++--
 drivers/pinctrl/mscc/pinctrl-serval.c       | 4 ++--
 drivers/pinctrl/mscc/pinctrl-servalt.c      | 4 ++--
 drivers/pinctrl/mvebu/pinctrl-armada-37xx.c | 4 ++--
 drivers/power/regulator/Kconfig             | 2 +-
 include/dm/device-internal.h                | 8 ++++----
 include/power/regulator.h                   | 2 +-
 20 files changed, 39 insertions(+), 37 deletions(-)

diff --git a/arch/x86/cpu/apollolake/spl.c b/arch/x86/cpu/apollolake/spl.c
index 089b37c59f8..1f75e1894b7 100644
--- a/arch/x86/cpu/apollolake/spl.c
+++ b/arch/x86/cpu/apollolake/spl.c
@@ -86,7 +86,7 @@ static int apl_flash_probe(struct udevice *dev)
 /*
  * Manually set the parent of the SPI flash to SPI, since dtoc doesn't. We also
  * need to allocate the parent_platdata since by the time this function is
- * called device_bind() has already gone past that step.
+ * called device_bind_offset() has already gone past that step.
  */
 static int apl_flash_bind(struct udevice *dev)
 {
diff --git a/drivers/clk/clk.c b/drivers/clk/clk.c
index 319808d433f..1fa9bec6fea 100644
--- a/drivers/clk/clk.c
+++ b/drivers/clk/clk.c
@@ -36,7 +36,7 @@ int clk_register(struct clk *clk, const char *drv_name,
 		return -ENOENT;
 	}
 
-	ret = device_bind(parent, drv, name, NULL, -1, &clk->dev);
+	ret = device_bind_offset(parent, drv, name, NULL, -1, &clk->dev);
 	if (ret) {
 		printf("%s: CLK: %s driver bind error [%d]!\n", __func__, name,
 		       ret);
diff --git a/drivers/core/device.c b/drivers/core/device.c
index 4b3dcb3b379..081dd1f7780 100644
--- a/drivers/core/device.c
+++ b/drivers/core/device.c
@@ -232,9 +232,9 @@ int device_bind_with_driver_data(struct udevice *parent,
 				  0, devp);
 }
 
-int device_bind(struct udevice *parent, const struct driver *drv,
-		const char *name, void *platdata, int of_offset,
-		struct udevice **devp)
+int device_bind_offset(struct udevice *parent, const struct driver *drv,
+		       const char *name, void *platdata, int of_offset,
+		       struct udevice **devp)
 {
 	return device_bind_common(parent, drv, name, platdata, 0,
 				  offset_to_ofnode(of_offset), 0, devp);
diff --git a/drivers/gpio/mt7621_gpio.c b/drivers/gpio/mt7621_gpio.c
index 612413e17bc..b64bc838a31 100644
--- a/drivers/gpio/mt7621_gpio.c
+++ b/drivers/gpio/mt7621_gpio.c
@@ -157,8 +157,8 @@ static int gpio_mediatek_bind(struct udevice *parent)
 		plat->gpio_count = MTK_BANK_WIDTH;
 		plat->bank = bank;
 
-		ret = device_bind(parent, parent->driver,
-				  plat->bank_name, plat, -1, &dev);
+		ret = device_bind_offset(parent, parent->driver,
+					 plat->bank_name, plat, -1, &dev);
 		if (ret)
 			return ret;
 
diff --git a/drivers/gpio/s5p_gpio.c b/drivers/gpio/s5p_gpio.c
index c78227f4da3..4f9fedd6129 100644
--- a/drivers/gpio/s5p_gpio.c
+++ b/drivers/gpio/s5p_gpio.c
@@ -332,8 +332,8 @@ static int gpio_exynos_bind(struct udevice *parent)
 			return -ENOMEM;
 
 		plat->bank_name = fdt_get_name(blob, node, NULL);
-		ret = device_bind(parent, parent->driver,
-				  plat->bank_name, plat, -1, &dev);
+		ret = device_bind_offset(parent, parent->driver,
+					 plat->bank_name, plat, -1, &dev);
 		if (ret)
 			return ret;
 
diff --git a/drivers/gpio/sunxi_gpio.c b/drivers/gpio/sunxi_gpio.c
index 02c3471b568..f18f0c8152c 100644
--- a/drivers/gpio/sunxi_gpio.c
+++ b/drivers/gpio/sunxi_gpio.c
@@ -305,8 +305,8 @@ static int gpio_sunxi_bind(struct udevice *parent)
 		plat->bank_name = gpio_bank_name(soc_data->start + bank);
 		plat->gpio_count = SUNXI_GPIOS_PER_BANK;
 
-		ret = device_bind(parent, parent->driver,
-					plat->bank_name, plat, -1, &dev);
+		ret = device_bind_offset(parent, parent->driver,
+					 plat->bank_name, plat, -1, &dev);
 		if (ret)
 			return ret;
 		dev_set_of_offset(dev, dev_of_offset(parent));
diff --git a/drivers/gpio/tegra186_gpio.c b/drivers/gpio/tegra186_gpio.c
index 6626b5415a3..a518a395cab 100644
--- a/drivers/gpio/tegra186_gpio.c
+++ b/drivers/gpio/tegra186_gpio.c
@@ -190,8 +190,8 @@ static int tegra186_gpio_bind(struct udevice *parent)
 		plat->name = ctlr_data->ports[port].name;
 		plat->regs = &(regs[ctlr_data->ports[port].offset / 4]);
 
-		ret = device_bind(parent, parent->driver, plat->name, plat,
-				  -1, &dev);
+		ret = device_bind_offset(parent, parent->driver, plat->name,
+					 plat, -1, &dev);
 		if (ret)
 			return ret;
 		dev_set_of_offset(dev, dev_of_offset(parent));
diff --git a/drivers/gpio/tegra_gpio.c b/drivers/gpio/tegra_gpio.c
index 912577a5719..0056171fc51 100644
--- a/drivers/gpio/tegra_gpio.c
+++ b/drivers/gpio/tegra_gpio.c
@@ -360,8 +360,9 @@ static int gpio_tegra_bind(struct udevice *parent)
 			plat->base_gpio = TEGRA_GPIOS_PER_PORT * base_port;
 			plat->port_name = gpio_port_name(base_port);
 
-			ret = device_bind(parent, parent->driver,
-					  plat->port_name, plat, -1, &dev);
+			ret = device_bind_offset(parent, parent->driver,
+						 plat->port_name, plat, -1,
+						 &dev);
 			if (ret)
 				return ret;
 			dev_set_of_offset(dev, dev_of_offset(parent));
diff --git a/drivers/net/mvpp2.c b/drivers/net/mvpp2.c
index 8f790a8b44c..df77a0d5e8e 100644
--- a/drivers/net/mvpp2.c
+++ b/drivers/net/mvpp2.c
@@ -5477,7 +5477,7 @@ static int mvpp2_base_bind(struct udevice *parent)
 		sprintf(name, "mvpp2-%d", id);
 
 		/* Create child device UCLASS_ETH and bind it */
-		device_bind(parent, &mvpp2_driver, name, plat, subnode, &dev);
+		device_bind_offset(parent, &mvpp2_driver, name, plat, subnode, &dev);
 		dev_set_of_offset(dev, subnode);
 	}
 
diff --git a/drivers/pinctrl/broadcom/pinctrl-bcm283x.c b/drivers/pinctrl/broadcom/pinctrl-bcm283x.c
index 41da8141232..54928a607cb 100644
--- a/drivers/pinctrl/broadcom/pinctrl-bcm283x.c
+++ b/drivers/pinctrl/broadcom/pinctrl-bcm283x.c
@@ -125,8 +125,9 @@ int bcm283x_pinctl_probe(struct udevice *dev)
 	struct udevice *pdev;
 
 	/* Create GPIO device as well */
-	ret = device_bind(dev, lists_driver_lookup_name("gpio_bcm2835"),
-			  "gpio_bcm2835", NULL, dev_of_offset(dev), &pdev);
+	ret = device_bind_offset(dev, lists_driver_lookup_name("gpio_bcm2835"),
+				 "gpio_bcm2835", NULL, dev_of_offset(dev),
+				 &pdev);
 	if (ret) {
 		/*
 		 * While we really want the pinctrl driver to work to make
diff --git a/drivers/pinctrl/meson/pinctrl-meson.c b/drivers/pinctrl/meson/pinctrl-meson.c
index d4539b02d88..45a1ccf58d6 100644
--- a/drivers/pinctrl/meson/pinctrl-meson.c
+++ b/drivers/pinctrl/meson/pinctrl-meson.c
@@ -419,7 +419,7 @@ int meson_pinctrl_probe(struct udevice *dev)
 	sprintf(name, "meson-gpio");
 
 	/* Create child device UCLASS_GPIO and bind it */
-	device_bind(dev, priv->data->gpio_driver, name, NULL, gpio, &gpio_dev);
+	device_bind_offset(dev, priv->data->gpio_driver, name, NULL, gpio, &gpio_dev);
 	dev_set_of_offset(gpio_dev, gpio);
 
 	return 0;
diff --git a/drivers/pinctrl/mscc/pinctrl-jr2.c b/drivers/pinctrl/mscc/pinctrl-jr2.c
index 72a9470854e..fc730b79d6a 100644
--- a/drivers/pinctrl/mscc/pinctrl-jr2.c
+++ b/drivers/pinctrl/mscc/pinctrl-jr2.c
@@ -299,8 +299,8 @@ static int jr2_pinctrl_probe(struct udevice *dev)
 	if (ret)
 		return ret;
 
-	ret = device_bind(dev, &jr2_gpio_driver, "jr2-gpio", NULL,
-			  dev_of_offset(dev), NULL);
+	ret = device_bind_offset(dev, &jr2_gpio_driver, "jr2-gpio", NULL,
+				 dev_of_offset(dev), NULL);
 
 	if (ret)
 		return ret;
diff --git a/drivers/pinctrl/mscc/pinctrl-luton.c b/drivers/pinctrl/mscc/pinctrl-luton.c
index 17fbc53c257..4fb17984abe 100644
--- a/drivers/pinctrl/mscc/pinctrl-luton.c
+++ b/drivers/pinctrl/mscc/pinctrl-luton.c
@@ -165,8 +165,8 @@ int luton_pinctrl_probe(struct udevice *dev)
 	if (ret)
 		return ret;
 
-	ret = device_bind(dev, &luton_gpio_driver, "luton-gpio", NULL,
-			  dev_of_offset(dev), NULL);
+	ret = device_bind_offset(dev, &luton_gpio_driver, "luton-gpio", NULL,
+				 dev_of_offset(dev), NULL);
 
 	return 0;
 }
diff --git a/drivers/pinctrl/mscc/pinctrl-ocelot.c b/drivers/pinctrl/mscc/pinctrl-ocelot.c
index 49e026bc98b..12ecad7a6e9 100644
--- a/drivers/pinctrl/mscc/pinctrl-ocelot.c
+++ b/drivers/pinctrl/mscc/pinctrl-ocelot.c
@@ -181,8 +181,8 @@ int ocelot_pinctrl_probe(struct udevice *dev)
 	if (ret)
 		return ret;
 
-	ret = device_bind(dev, &ocelot_gpio_driver, "ocelot-gpio", NULL,
-			  dev_of_offset(dev), NULL);
+	ret = device_bind_offset(dev, &ocelot_gpio_driver, "ocelot-gpio", NULL,
+				 dev_of_offset(dev), NULL);
 
 	return ret;
 }
diff --git a/drivers/pinctrl/mscc/pinctrl-serval.c b/drivers/pinctrl/mscc/pinctrl-serval.c
index d59f08d4eb7..93b31d20833 100644
--- a/drivers/pinctrl/mscc/pinctrl-serval.c
+++ b/drivers/pinctrl/mscc/pinctrl-serval.c
@@ -209,8 +209,8 @@ static int serval_pinctrl_probe(struct udevice *dev)
 	if (ret)
 		return ret;
 
-	ret = device_bind(dev, &serval_gpio_driver, "serval-gpio", NULL,
-			  dev_of_offset(dev), NULL);
+	ret = device_bind_offset(dev, &serval_gpio_driver, "serval-gpio", NULL,
+				 dev_of_offset(dev), NULL);
 
 	if (ret)
 		return ret;
diff --git a/drivers/pinctrl/mscc/pinctrl-servalt.c b/drivers/pinctrl/mscc/pinctrl-servalt.c
index 592b7c547b7..9bbc7698a52 100644
--- a/drivers/pinctrl/mscc/pinctrl-servalt.c
+++ b/drivers/pinctrl/mscc/pinctrl-servalt.c
@@ -245,8 +245,8 @@ static int servalt_pinctrl_probe(struct udevice *dev)
 	if (ret)
 		return ret;
 
-	ret = device_bind(dev, &servalt_gpio_driver, "servalt-gpio", NULL,
-			  dev_of_offset(dev), NULL);
+	ret = device_bind_offset(dev, &servalt_gpio_driver, "servalt-gpio", NULL,
+				 dev_of_offset(dev), NULL);
 
 	if (ret)
 		return ret;
diff --git a/drivers/pinctrl/mvebu/pinctrl-armada-37xx.c b/drivers/pinctrl/mvebu/pinctrl-armada-37xx.c
index fb497803b93..7bbeb413ba5 100644
--- a/drivers/pinctrl/mvebu/pinctrl-armada-37xx.c
+++ b/drivers/pinctrl/mvebu/pinctrl-armada-37xx.c
@@ -567,8 +567,8 @@ static int armada_37xx_gpiochip_register(struct udevice *parent,
 	sprintf(name, "armada-37xx-gpio");
 
 	/* Create child device UCLASS_GPIO and bind it */
-	device_bind(parent, &armada_37xx_gpio_driver, name, NULL, subnode,
-		    &dev);
+	device_bind_offset(parent, &armada_37xx_gpio_driver, name, NULL,
+			   subnode, &dev);
 	dev_set_of_offset(dev, subnode);
 
 	return 0;
diff --git a/drivers/power/regulator/Kconfig b/drivers/power/regulator/Kconfig
index d431102462a..a6f78d96706 100644
--- a/drivers/power/regulator/Kconfig
+++ b/drivers/power/regulator/Kconfig
@@ -11,7 +11,7 @@ config DM_REGULATOR
 	- 'include/power/regulator.h'
 	- 'drivers/power/pmic/pmic-uclass.c'
 	- 'drivers/power/pmic/regulator-uclass.c'
-	It's important to call the device_bind() with the proper node offset,
+	It's important to call the device_bind_offset() with the proper node offset,
 	when binding the regulator devices. The pmic_bind_childs() can be used
 	for this purpose if PMIC I/O driver is implemented or dm_scan_fdt_dev()
 	otherwise. Detailed information can be found in the header file.
diff --git a/include/power/regulator.h b/include/power/regulator.h
index 7f278e8c7dc..4d58a436fea 100644
--- a/include/power/regulator.h
+++ b/include/power/regulator.h
@@ -48,7 +48,7 @@
  * If regulator-name property is not provided, node name will be chosen.
  *
  * Regulator bind:
- * For each regulator device, the device_bind() should be called with passed
+ * For each regulator device, the device_bind_offset() should be called with passed
  * device tree offset. This is required for this uclass's '.post_bind' method,
  * which does the scan on the device node, for the 'regulator-name' constraint.
  * If the parent is not a PMIC device, and the child is not bind by function:
diff --git a/include/dm/device-internal.h b/include/dm/device-internal.h
index c5d7ec0650f..59d3be09a1e 100644
--- a/include/dm/device-internal.h
+++ b/include/dm/device-internal.h
@@ -16,7 +16,7 @@ struct device_node;
 struct udevice;
 
 /**
  * device_bind() - Create a device and bind it to a driver
  *
  * Called to set up a new device attached to a driver. The device will either
  * have platdata, or a device tree node which can be used to create the
@@ -36,9 +36,9 @@ struct udevice;
  * @devp: if non-NULL, returns a pointer to the bound device
  * @return 0 if OK, -ve on error
  */
-int device_bind(struct udevice *parent, const struct driver *drv,
-		const char *name, void *platdata, int of_offset,
-		struct udevice **devp);
+int device_bind_offset(struct udevice *parent, const struct driver *drv,
+		       const char *name, void *platdata, int of_offset,
+		       struct udevice **devp);
 
 int device_bind_ofnode(struct udevice *parent, const struct driver *drv,
 		       const char *name, void *platdata, ofnode node,
@@ -16,7 +16,7 @@ struct device_node;
 
 /**
- * device_bind() - Create a device and bind it to a driver
+ * device_bind_offset() - Create a device and bind it to a driver
  *
  * Called to set up a new device attached to a driver. The device will either
-- 
2.29.2.454.gaff20da3a2-goog



More information about the U-Boot mailing list